<?php

/**
 * @file
 * Contains \Drupal\gpa_calculator\Form\GpaCalculatorSettingsForm.
 */

namespace Drupal\gpa_calculator\Form;

use Drupal\Component\Utility\String;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form to configure maintenance settings for this site.
 */
class GpaCalculatorSettingsForm extends ConfigFormBase {
  /**
   * {@inheritdoc}
   */
  public function getFormID() {
    return 'gpa_calculator_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('gpa_calculator.gpa');
    $form['gpa_calculator_school_name'] = array(
      '#type' => 'textfield',
      '#title' => t('School'),
      '#description' => t('Enter you school\'s name here. If blank, block subject will read as "GPA Calculator."'),
      '#default_value' => $config->get('school_name'),
    );

    $form['gpa_calculator_instructions'] = array(
      '#type' => 'textarea',
      '#title' => t('Instructions'),
      '#description' => t('Provide instructions or a description for your GPA calculator.'),
      '#default_value' => $config->get('instructions'),
    );

    $grades_options_example = ' 4.0|A ';
    $grades_options_example .= '3.67|A- ';
    $grades_options_example .= '3.33|B+ ';
    $grades_options_example .= '3.0|B ';
    $grades_options_example .= '2.67|C+ ';
    $grades_options_example .= '2.33|C ';
    $grades_options_example .= '2.0|C- ';
    $grades_options_example .= '1.67|D+ ';
    $grades_options_example .= '1.33|D ';
    $grades_options_example .= '1.0|D- ';
    $grades_options_example .= '0.0|F';

    $grades_description = t('Enter grade options for the select box values.  Key-value pairs must be entered separated by pipes. i.e. safe_key|Some readable option.  If blank, default vales will be:') . $grades_options_example;

    $form['gpa_calculator_grades'] = array(
      '#type' => 'textarea',
      '#title' => t('Grades'),
      '#description' => $grades_description,
      '#default_value' => $config->get('grades'),
    );

    $form['cumulative_gpa_instructions'] = array(
      '#type' => 'textfield',
      '#title' => t('Previous Cumulative GPA Instructions'),
      '#description' => t('Enter instructions to display as the description under "Previous Cumulative GPA" on the GPA Calculator.'),
      '#maxlength' => 255,
      '#default_value' => $config->get('cumulative_gpa_instructions'),
    );

    $form['cumulative_credits_earned_instructions'] = array(
      '#type' => 'textfield',
      '#title' => t('Previous Cumulative Credits Earned Instructions'),
      '#description' => t('Enter instructions to display as the description under "Previous Cumulative Credits Earned" on the GPA Calculator.'),
      '#maxlength' => 255,
      '#default_value' => $config->get('cumulative_credits_earned_instructions'),
    );

    return parent::buildForm($form, $form_state);
  }
  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('gpa_calculator.gpa')
      ->set('school_name', String::checkPlain($form_state->getValue('gpa_calculator_school_name')))
      ->set('instructions', String::checkPlain($form_state->getValue('gpa_calculator_instructions')))
      ->set('grades', String::checkPlain($form_state->getValue('gpa_calculator_grades')))
      ->set('cumulative_gpa_instructions', String::checkPlain($form_state->getValue('cumulative_gpa_instructions')))
      ->set('cumulative_credits_earned_instructions', String::checkPlain($form_state->getValue('cumulative_credits_earned_instructions')))
      ->save();
    parent::submitForm($form, $form_state);
  }
}
